'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.normalizeSourceRoot = normalizeSourceRoot;
exports.normalizeFilename = normalizeFilename;
exports.checkAndRemovePrefix = checkAndRemovePrefix;
exports.transformPath = transformPath;

var _path = require('path');

function normalizeSourceRoot(sourceRoot) {
  var suffix = arguments.length <= 1 || arguments[1] === undefined ? '' : arguments[1];

  if (typeof sourceRoot !== 'string') sourceRoot = undefined;
  if (typeof suffix !== 'string') suffix = '';

  if (!sourceRoot) sourceRoot = process.cwd();

  return [sourceRoot, (0, _path.join)(sourceRoot, suffix)];
}

function normalizeFilename(filename, sourceRoot, suffixedSourceRoot) {
  if (typeof filename !== 'string') return null;
  if (typeof sourceRoot !== 'string') return null;
  if (typeof suffixedSourceRoot !== 'string') return null;

  if (filename === 'unknown') return null;

  var absoluteFilename = null;

  // Some babel wrappers supply an absolute path already
  // so we need to check for that.
  if ((0, _path.isAbsolute)(filename)) {
    absoluteFilename = filename;
  } else {
    absoluteFilename = (0, _path.join)(sourceRoot, filename);
  }

  return (0, _path.relative)(suffixedSourceRoot, absoluteFilename);
}

function checkAndRemovePrefix(path, prefix) {
  if (path.startsWith(prefix)) {
    return path.substring(prefix.length);
  } else {
    return null;
  }
}

function transformPath(importPath, filePath, sourceRoot) {
  var importPathName = (0, _path.basename)(importPath);

  var absoluteImportPath = (0, _path.dirname)((0, _path.join)(sourceRoot, importPath));
  var absoluteFilePath = (0, _path.dirname)((0, _path.join)(sourceRoot, filePath));
  var relativeImportPath = (0, _path.relative)(absoluteFilePath, absoluteImportPath);

  return './' + (0, _path.join)(relativeImportPath, importPathName);
}